@@ -49,35 +49,6 @@ from colorama import Fore, Style
      mike [~at~] pennington [/dot\] net
 """
 
-
-class _SharedCounter(object):
-    """ A synchronized shared counter.
-
-    The locking done by multiprocessing.Value ensures that only a single
-    process or thread may read or write the in-memory ctypes object. However,
-    in order to do n += 1, Python performs a read followed by a write, so a
-    second process may read the old value before the new one is written by the
-    first process. The solution is to use a multiprocessing.Lock to guarantee
-    the atomicity of the modifications to Value.
-
-    This class comes almost entirely from Eli Bendersky's blog:
-    http://eli.thegreenplace.net/2012/01/04/shared-counter-with-pythons-multiprocessing/
-
-    """
-
-    def __init__(self, n=0):
-        self.count = multiprocessing.Value("i", n)
-
-    def increment(self, n=1):
-        """ Increment the counter by n (default = 1) """
-        with self.count.get_lock():
-            self.count.value += n
-
-    @property
-    def value(self):
-        """ Return the value of the counter """
-        return self.count.value
-
 class SharedCounter(object):
     """ A synchronized shared counter.
     The locking done by multiprocessing.Value ensures that only a single
@@ -111,47 +82,6 @@ class SharedCounter(object):
 #Code license is GPLv3 according to github.com/vterron/lemon/setup.py
 #
 ################################################################################
-class _py23_mp_queue(mpq.Queue):
-    """ A portable implementation of multiprocessing.Queue.
-
-    Because of multithreading / multiprocessing semantics, Queue.qsize() may
-    raise the NotImplementedError exception on Unix platforms like Mac OS X
-    where sem_getvalue() is not implemented. This subclass addresses this
-    problem by using a synchronized shared counter (initialized to zero) and
-    increasing / decreasing its value every time the put() and get() methods
-    are called, respectively. This not only prevents NotImplementedError from
-    being raised, but also allows us to implement a reliable version of both
-    qsize() and empty().
-
-    """
-
-    def __init__(self, *args, **kwargs):
-        # Requires different __init__() based on Python2 vs Python3.4...
-        if sys.version_info >= (3, 4, 0):
-            super(py23_mp_queue, self).__init__(
-                *args, ctx=multiprocessing.get_context("spawn"), **kwargs
-            )
-        else:
-            super(py23_mp_queue, self).__init__(*args, **kwargs)
-        self.size = SharedCounter(0)
-        print("HERE {}".format(self.size.value))
-
-    def put(self, *args, **kwargs):
-        super(py23_mp_queue, self).put(*args, **kwargs)
-        self.size.increment(1)
-
-    def get(self, *args, **kwargs):
-        self.size.increment(-1)
-        return super(py23_mp_queue, self).get(*args, **kwargs)
-
-    def qsize(self):
-        """Reliable implementation of multiprocessing.Queue.qsize() """
-        return self.size.value
-
-    def empty(self):
-        """Reliable implementation of multiprocessing.Queue.empty() """
-        return not self.qsize()
-
 class py23_mp_queue(mpq.Queue):
     """ A portable implementation of multiprocessing.Queue.
     Because of multithreading / multiprocessing semantics, Queue.qsize() may
@@ -173,21 +103,21 @@ class py23_mp_queue(mpq.Queue):
             )
         else:
             super(py23_mp_queue, self).__init__(*args, **kwargs)
-        self._size = SharedCounter(0)
+        self.size = SharedCounter(0)
 
     def put(self, *args, **kwargs):
         # Infinite recursion possible if we don't use super() here
         super(py23_mp_queue, self).put(*args, **kwargs)
-        self._size.increment(1)
+        self.size.increment(1)
 
     def get(self, *args, **kwargs):
         item = super(py23_mp_queue, self).get(*args, **kwargs)
-        self._size.increment(-1)
+        self.size.increment(-1)
         return item
 
     def qsize(self):
         """ Reliable implementation of multiprocessing.Queue.qsize() """
-        return self._size.value
+        return self.size.value
 
     def empty(self):
         """ Reliable implementation of multiprocessing.Queue.empty() """
@@ -620,7 +550,7 @@ class TaskMgr(object):
                         self.worker_assignments.pop(w_id)  # Delete the key
                         finished = self.is_finished()
                     else:
-                        self.controller.to_q.put(task)  # Send to the controller
+                        self.controller.to_controller_q.put(task)  # Send to the controller
                         self.worker_assignments.pop(w_id)  # Delete the key
 
                 elif state == "__ERROR__":
@@ -705,7 +635,7 @@ class TaskMgr(object):
         while not finished:
             try:
                 ## Hot loops will queue a list of tasks...
-                tasklist = self.controller.from_q.get_nowait()
+                tasklist = self.controller.from_controller_q.get_nowait()
                 for task in tasklist:
                     if delay > 0.0:
                         task.worker_loop_delay = delay
@@ -906,5 +836,5 @@ class ControllerQueue(object):
 
     def __init__(self):
         ## to and from are with respect to the (client) controller object
-        self.to_q = py23_mp_queue()  # sent to the controller from TaskMgr
-        self.from_q = py23_mp_queue()  # sent from the controller to TaskMgr
+        self.to_controller_q = py23_mp_queue()  # sent to the controller from TaskMgr
+        self.from_controller_q = py23_mp_queue()  # sent from the controller to TaskMgr
